require "import"
import "android.widget.*"
import "android.view.*"
import "android.content.*"
import "android.app.AlertDialog"

activity.setTitle("O Nouă Extensie - Dezvoltator Sorin Lazăr")

local marginStanga, marginDreapta, marginSus, marginJos = 16, 16, 16, 16

local function afiseazaToast(mesaj)
    Toast.makeText(activity, mesaj, Toast.LENGTH_SHORT).show()
end

-- Funcție pentru eliminarea comentariilor dintr-o linie de cod
local function eliminaComentarii(linie)
    local indice = string.find(linie, "%-%-")
    if indice then
        return string.sub(linie, 1, indice -1)
    else
        return linie
    end
end

local layoutPrincipal = LinearLayout(activity)
layoutPrincipal.setOrientation(LinearLayout.VERTICAL)
layoutPrincipal.setPadding(marginStanga, marginSus, marginDreapta, marginJos)
layoutPrincipal.setBackgroundColor(0xFF000000)

local logo = TextView(activity)
logo.setText("Jieshuo Plus - Editor Cod")
logo.setTextSize(20)
logo.setTextColor(0xFFFFFFFF)
logo.setGravity(Gravity.CENTER)
layoutPrincipal.addView(logo)

local scrollView = ScrollView(activity)
local containerLines = LinearLayout(activity)
containerLines.setOrientation(LinearLayout.VERTICAL)
scrollView.addView(containerLines)
layoutPrincipal.addView(scrollView)

local function adaugaLinie(text, sterge)
    local lineLayout = LinearLayout(activity)
    lineLayout.setOrientation(LinearLayout.HORIZONTAL)
    lineLayout.setPadding(0, 8, 0, 8)
    lineLayout.setLayoutParams(LinearLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT))

    local editText = EditText(activity)
    editText.setText(text)
    editText.setTextColor(0xFFFFFFFF)
    editText.setHintTextColor(0xFFAAAAAA)
    editText.setBackgroundColor(0xFF333333)
    editText.setLayoutParams(LinearLayout.LayoutParams(0, ViewGroup.LayoutParams.WRAP_CONTENT, 1))
    editText.setPadding(8, 8, 8, 8)
    editText.setSingleLine(false)
    editText.setMinHeight(100)
    lineLayout.addView(editText)

    if sterge then
        local btnSterge = Button(activity)
        btnSterge.setText("Șterge")
        btnSterge.setTextColor(0xFFFFFFFF)
        btnSterge.setBackgroundColor(0xFFFF4444)
        btnSterge.setLayoutParams(LinearLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT))
        btnSterge.setOnClickListener{
            onClick = function()
                containerLines.removeView(lineLayout)
                afiseazaToast("Linia a fost ștearsă.")
            end
        }
        lineLayout.addView(btnSterge)
    end

    containerLines.addView(lineLayout)
end

local function adaugaElement(titlu, format, sterge)
    local dialog = AlertDialog.Builder(activity)
    dialog.setTitle("Adaugă " .. titlu)

    local layoutDialog = LinearLayout(activity)
    layoutDialog.setOrientation(LinearLayout.VERTICAL)
    layoutDialog.setPadding(16, 16, 16, 16)

    local input = EditText(activity)
    input.setHint("Introdu numele " .. titlu:lower())
    input.setTextColor(0xFF000000)
    input.setBackgroundColor(0xFFFFFFFF)
    layoutDialog.addView(input)

    local btnPasteDialog = Button(activity)
    btnPasteDialog.setText("Lipește >")
    btnPasteDialog.setTextColor(0xFFFFFFFF)
    btnPasteDialog.setBackgroundColor(0xFF4CAF50)
    btnPasteDialog.setLayoutParams(LinearLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT))
    btnPasteDialog.setOnClickListener{
        onClick = function()
            local clipboard = activity.getSystemService(Context.CLIPBOARD_SERVICE)
            local clip = clipboard.getPrimaryClip()
            if clip and clip.getItemCount() > 0 then
                local pasteText = tostring(clip.getItemAt(0).coerceToText(activity))
                input.setText(pasteText)
                afiseazaToast("Textul a fost lipit.")
            else
                Toast.makeText(activity, "Clipboard-ul este gol!", Toast.LENGTH_SHORT).show()
            end
        end
    }
    layoutDialog.addView(btnPasteDialog)

    dialog.setView(layoutDialog)

    dialog.setPositiveButton("OK", function()
        local valoare = tostring(input.getText())
        if valoare ~= "" then
            local linie = string.format(format, valoare)
            adaugaLinie(linie, sterge)
            afiseazaToast(titlu .. " adăugat cu succes!")
        else
            Toast.makeText(activity, "Numele " .. titlu:lower() .. " nu poate fi gol!", Toast.LENGTH_SHORT).show()
        end
    end)

    dialog.setNegativeButton("Anulează", nil)
    dialog.show()
end

local function adaugaAplicatie()
    adaugaElement("Aplicație", '">%s>7",', true)
end

local function adaugaFunctie()
    adaugaElement("Funcție", '"%%%s",', false)
end

local function adaugaExtensie()
    adaugaElement("Extensie", '"%%Extensii//%s",', false)
end

local function adaugaNumeObiect()
    adaugaElement("Nume Obiect", '"#%s>7",', true)
end

local function adaugaButon()
    adaugaElement("Buton", '"%s>8",', true)
end

local function copiazaText()
    local allLines = {}
    for i = 0, containerLines.getChildCount() - 1 do
        local child = containerLines.getChildAt(i)
        local editText = child.getChildAt(0)
        local lineText = tostring(editText.getText())
        local linieFaraComentariu = eliminaComentarii(lineText)
        linieFaraComentariu = linieFaraComentariu:gsub("^%s+", ""):gsub("%s+$", "")
        if linieFaraComentariu ~= "" then
            table.insert(allLines, linieFaraComentariu)
        end
    end
    local codComplet = "if service.click({{\n" .. table.concat(allLines, "\n") .. "\n}}) then\n    return true\nend"
    if codComplet ~= "if service.click({{\n}}) then\n    return true\nend" then
        local clipboard = activity.getSystemService(Context.CLIPBOARD_SERVICE)
        local clip = ClipData.newPlainText("Text copiat", codComplet)
        clipboard.setPrimaryClip(clip)
        Toast.makeText(activity, "Extensia a fost finalizată cu succes!", Toast.LENGTH_SHORT).show()

        local codSuplimentar = [[
if service.click({{
">Jieshuo Plus",
"Extensii>8",
"*Opțiun*>8",
"Nou>8",
"%Dictare$9000",
"Ok>8",
"%Inserare>7",
"Ok>8",
}}) then
    return true
end
]]
        local success, err = pcall(function()
            loadstring(codSuplimentar)()
        end)
        if not success then
            Toast.makeText(activity, "Eroare la finalizare: " .. err, Toast.LENGTH_LONG).show()
        end
    else
        Toast.makeText(activity, "Codul este gol!", Toast.LENGTH_SHORT).show()
    end
end

local function afiseazaInformatii()
    local mesaj = [[
Utilizare:
1. Introdu numele aplicației corect.
2. Utilizează funcțiile necesare pentru a-ți optimiza codul.
3. Verifică extensiile înainte de a le integra.
4. Copiază numele obiectelor folosind comanda vocală.
5. Utilizează butoanele pentru a focaliza și a interacționa automat.
    ]]
    AlertDialog.Builder(activity)
        .setTitle("Informații")
        .setMessage(mesaj)
        .setPositiveButton("OK", nil)
        .show()
end

local function creazaButon(text, onClick, backgroundColor)
    local btn = Button(activity)
    btn.setText(text)
    btn.setTextColor(0xFFFFFFFF)
    btn.setBackgroundColor(backgroundColor or 0xFF2196F3)
    btn.setLayoutParams(LinearLayout.LayoutParams(0, ViewGroup.LayoutParams.WRAP_CONTENT, 1))
    btn.setOnClickListener(onClick)
    return btn
end

local baraActiuni1 = LinearLayout(activity)
baraActiuni1.setOrientation(LinearLayout.HORIZONTAL)
baraActiuni1.setLayoutParams(LinearLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT))
baraActiuni1.setPadding(0, 16, 0, 16)

baraActiuni1.addView(creazaButon("Aplicație", adaugaAplicatie, 0xFF3F51B5))
baraActiuni1.addView(creazaButon("Funcție", adaugaFunctie, 0xFF3F51B5))
baraActiuni1.addView(creazaButon("Extensie", adaugaExtensie, 0xFF3F51B5))
baraActiuni1.addView(creazaButon("Nume Obiect", adaugaNumeObiect, 0xFF3F51B5))
layoutPrincipal.addView(baraActiuni1)

local baraActiuni2 = LinearLayout(activity)
baraActiuni2.setOrientation(LinearLayout.HORIZONTAL)
baraActiuni2.setLayoutParams(LinearLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT))
baraActiuni2.setPadding(0, 16, 0, 16)

baraActiuni2.addView(creazaButon("Adaugă un Buton", adaugaButon, 0xFF009688))
baraActiuni2.addView(creazaButon("Finalizare Creare Extensie", copiazaText, 0xFFFFC107))
baraActiuni2.addView(creazaButon("Informații", afiseazaInformatii, 0xFF9C27B0))
layoutPrincipal.addView(baraActiuni2)

activity.setContentView(layoutPrincipal)